<?php
declare(strict_types=1);

namespace addianto\LionGame\Backend\Service;

use Google_Service_Sheets as GoogleSheetsAPI;
use Google_Service_Sheets_ValueRange as ValueRange;
use Google_Service_Sheets_AppendValuesResponse as AppendValuesResponse;
use is_null;

class SheetsService
{
    private static ?SheetsService $instance = null;
    private GoogleSheetsAPI $api;
    private string $spreadsheetId;

    private function __construct(GoogleSheetsAPI $api, string $spreadsheetId)
    {
        $this->api = $api;
        $this->spreadsheetId = $spreadsheetId;
    }

    public function getValues(string $range): array
    {
        $values = array();

        try {
            $response = $this->api->spreadsheets_values
                ->get($this->spreadsheetId, $range);

            $values = $response->getValues();
        } catch (Exception $e) {
            error_log($e->getMessage());
            error_log($e->getTraceAsString());
        }

        return $values;
    }

    public function appendValues(string $range, array $values): bool
    {
        $isAppended = false;

        try {
            $body = new ValueRange([
                "majorDimension" => "ROWS",
                "values" => $values,
            ]);

            $optionalParameters = array(
                "insertDataOption" => "INSERT_ROWS",
                "valueInputOption" => "RAW",
            );

            $this->api->spreadsheets_values
                ->append($this->spreadsheetId, $range, $body, $optionalParameters);

            $isAppended = true;
        } catch (Exception $e) {
            error_log($e->getMessage());
            error_log($e->getTraceAsString());
        }

        return $isAppended;
    }

    public static function getInstance(GoogleSheetsAPI $api, string $spreadsheetId): SheetsService
    {
        if (is_null(self::$instance)) {
            self::$instance = new SheetsService($api, $spreadsheetId);
        }

        return self::$instance;
    }
}
